package com.develou.a2_tipos_de_preferencias

import android.os.Bundle
import android.util.Log
import androidx.preference.MultiSelectListPreference
import androidx.preference.Preference
import androidx.preference.PreferenceFragmentCompat

class SettingsFragment : PreferenceFragmentCompat() {

    override fun onCreatePreferences(savedInstanceState: Bundle?, rootKey: String?) {
        setPreferencesFromResource(R.xml.preferences, rootKey)

        setUpBuildVersion()
        setUpAccountSummary()
    }

    private fun setUpBuildVersion() {
        val buildVersion: Preference? = findPreference("buildVersion")

        buildVersion?.summary = BuildConfig.VERSION_NAME

        buildVersion?.setOnPreferenceClickListener {
            Log.d("SettingsFragment", "\"${it.title}\" fue clickeada")
            false
        }
    }

    private fun setUpAccountSummary() {
        val accountSummary: MultiSelectListPreference? = findPreference("accountSummary")
        accountSummary?.run {
            setSummary(values) // Texto secundario inicial
            setOnPreferenceChangeListener { _, newValue ->
                val newValues = newValue as Set<String>
                accountSummary.setSummary(newValues) // Texto secundario al cambiar
                true
            }
        }
    }

    fun MultiSelectListPreference.setSummary(newValues: Set<String>) {
        summary = if (newValues.isEmpty())
            "Sin envío"
        else
            newValues.joinToString(", ") { value ->
                entries[findIndexOfValue(value)]
            }
    }
}